Home
last modified time | relevance | path

Searched refs:transpose (Results 1 – 25 of 33) sorted by relevance

12

/freebsd/crypto/openssl/crypto/sm4/asm/
H A Dvpsm4-armv8.pl110 sub transpose() { subroutine
944 &transpose(@vtmp,@datax);
945 &transpose(@data,@datax);
982 &transpose(@vtmp,@datax);
1024 &transpose(@vtmp,@datax);
1043 &transpose(@vtmp,@datax);
1330 &transpose(@data,@vtmp);
1331 &transpose(@datax,@vtmp);
1335 &transpose(@vtmp,@datax);
1336 &transpose(@data,@datax);
[all …]
H A Dvpsm4_ex-armv8.pl113 sub transpose() { subroutine
943 &transpose(@vtmp,@datax);
944 &transpose(@data,@datax);
981 &transpose(@vtmp,@datax);
1023 &transpose(@vtmp,@datax);
1042 &transpose(@vtmp,@datax);
1339 &transpose(@data,@vtmp);
1340 &transpose(@datax,@vtmp);
1344 &transpose(@vtmp,@datax);
1345 &transpose(@data,@datax);
[all …]
/freebsd/contrib/llvm-project/clang/include/clang/Basic/
H A DBuiltinsX86_64.td242 let Features = "amx-transpose", Attributes = [NoThrow] in {
246 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in {
250 let Features = "amx-transpose", Attributes = [NoThrow] in {
254 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in {
258 let Features = "amx-transpose", Attributes = [NoThrow] in {
262 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in {
266 let Features = "amx-transpose", Attributes = [NoThrow] in {
270 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in {
274 let Features = "amx-transpose", Attributes = [NoThrow] in {
278 let Features = "amx-bf16,amx-transpose", Attributes = [NoThrow] in {
[all …]
H A DBuiltinsAMDGPU.def649 TARGET_BUILTIN(__builtin_amdgcn_global_load_tr4_b64_v2i32, "V2iV2i*1", "nc", "transpose-load-f4f6-i…
651 TARGET_BUILTIN(__builtin_amdgcn_global_load_tr6_b96_v3i32, "V3iV3i*1", "nc", "transpose-load-f4f6-i…
655 TARGET_BUILTIN(__builtin_amdgcn_ds_load_tr4_b64_v2i32, "V2iV2i*3", "nc", "transpose-load-f4f6-insts…
657 TARGET_BUILTIN(__builtin_amdgcn_ds_load_tr6_b96_v3i32, "V3iV3i*3", "nc", "transpose-load-f4f6-insts…
/freebsd/contrib/llvm-project/llvm/include/llvm/CodeGen/PBQP/
H A DReductionRules.h97 new Matrix(G.getEdgeCosts(YXEId).transpose()) : in applyR2()
101 new Matrix(G.getEdgeCosts(ZXEId).transpose()) : in applyR2()
138 G.updateEdgeCosts(YZEId, Delta.transpose() + YZECosts); in applyR2()
H A DMath.h194 Matrix transpose() const { in transpose() function
/freebsd/crypto/openssl/crypto/chacha/asm/
H A Dchacha-armv8-sve.pl289 sub transpose() { subroutine
426 &transpose($xa0,$xa1,$xa2,$xa3,$xb0,$xb1,$xb2,$xb3);
430 &transpose($xc0,$xc1,$xc2,$xc3,$xd0,$xd1,$xd2,$xd3);
512 &transpose($xa0,$xb0,$xc0,$xd0,$xa1,$xb1,$xc1,$xd1);
515 &transpose($xa2,$xb2,$xc2,$xd2,$xa3,$xb3,$xc3,$xd3);
518 &transpose($xa0,$xa1,$xa2,$xa3,$xb0,$xb1,$xb2,$xb3);
521 &transpose($xc0,$xc1,$xc2,$xc3,$xd0,$xd1,$xd2,$xd3);
/freebsd/contrib/byacc/
H A Dlalr.c13 static Value_t **transpose(Value_t **R, int n);
426 new_includes = transpose(includes, ngotos); in build_relations()
466 transpose(Value_t **R2, int n) in transpose() function
/freebsd/contrib/tcsh/
H A Ddot.tcshrc87 # Set status to ^G in order to keep using ^T for transpose-char.
/freebsd/contrib/llvm-project/llvm/include/llvm/TargetParser/
H A DX86TargetParser.def269 X86_FEATURE (AMX_TRANSPOSE, "amx-transpose")
/freebsd/contrib/llvm-project/llvm/lib/Target/X86/
H A DX86.td274 def FeatureAMXTRANSPOSE : SubtargetFeature<"amx-transpose", "HasAMXTRANSPOSE", "true",
275 "Support AMX amx-transpose instructions",
/freebsd/contrib/llvm-project/llvm/lib/Target/AArch64/
H A DAArch64SchedThunderX3T110.td1638 // ASIMD transpose
1682 // ASIMD transpose
H A DAArch64SchedNeoverseV1.td1120 // ASIMD transpose
1460 // Predicate transpose
H A DAArch64SchedAmpere1.td1136 // -- transpose
H A DAArch64SchedAmpere1B.td1143 // -- transpose
H A DAArch64SchedNeoverseN2.td1224 // ASIMD transpose
1608 // Predicate transpose
H A DAArch64SchedNeoverseN3.td1186 // ASIMD transpose
1578 // Predicate transpose
H A DAArch64SchedNeoverseN1.td760 // ASIMD transpose
H A DAArch64SchedNeoverseV2.td1700 // ASIMD transpose
2093 // Predicate transpose
H A DAArch64SchedA510.td622 // Predicate transpose
H A DAArch64SchedA320.td644 // Predicate transpose
/freebsd/crypto/openssl/doc/designs/quic-design/
H A Dconnection-state-machine.md495 We transpose the above table to sort by events rather than states, to discern
/freebsd/crypto/heimdal/
H A DChangeLog.2001685 * lib/krb5/cache.c (krb5_cc_next_cred): transpose last two
/freebsd/contrib/llvm-project/llvm/lib/Target/ARM/
H A DARMScheduleA57.td1239 // ASIMD transpose
/freebsd/contrib/llvm-project/llvm/lib/Target/AMDGPU/
H A DAMDGPU.td1115 def FeatureTransposeLoadF4F6Insts : SubtargetFeature<"transpose-load-f4f6-insts",

12